import { ReleasePR } from './release-pr';
import { GitHubRelease, GitHubReleaseResponse } from './github-release';
import { ReleaseType } from './releasers';
import { GitHub, GitHubTag } from './github';
import { ManifestFactoryOptions, ReleasePRFactoryOptions, GitHubReleaseFactoryOptions, GitHubFactoryOptions } from '.';
import { ManifestGitHubReleaseResult, Manifest } from './manifest';
export declare type ManifestMethod = 'pullRequest' | 'githubRelease';
export declare type ReleasePRMethod = 'run' | 'latestTag';
export declare type GitHubReleaseMethod = 'run';
export declare type Method = ManifestMethod | ReleasePRMethod | GitHubReleaseMethod;
export declare type ManifestCommand = 'manifest-pr' | 'manifest-release';
export declare type ReleasePRCommand = 'release-pr' | 'latest-tag';
export declare type GitHubReleaseCommand = 'github-release';
export declare type ManifestCallResult = Promise<number | undefined | ManifestGitHubReleaseResult>;
export declare type ReleasePRCallResult = Promise<number | GitHubTag | undefined>;
export declare type GitHubReleaseCallResult = Promise<GitHubReleaseResponse | undefined>;
export declare type CallResult = ManifestCallResult | ReleasePRCallResult | GitHubReleaseCallResult;
declare function runCommand(command: ManifestCommand, options: ManifestFactoryOptions): ManifestCallResult;
declare function runCommand(command: ReleasePRCommand, options: ReleasePRFactoryOptions): ReleasePRCallResult;
declare function runCommand(command: GitHubReleaseCommand, options: GitHubReleaseFactoryOptions): GitHubReleaseCallResult;
declare function call(instance: Manifest, method: ManifestMethod): ManifestCallResult;
declare function call(instance: ReleasePR, method: ReleasePRMethod): ReleasePRCallResult;
declare function call(instance: GitHubRelease, method: GitHubReleaseMethod): GitHubReleaseCallResult;
declare function manifest(options: ManifestFactoryOptions): Manifest;
declare function githubRelease(options: GitHubReleaseFactoryOptions): GitHubRelease;
declare function releasePR(options: ReleasePRFactoryOptions): ReleasePR;
declare function gitHubInstance(options: GitHubFactoryOptions): GitHub;
declare function releasePRClass(releaseType?: ReleaseType): typeof ReleasePR;
export declare const factory: {
    gitHubInstance: typeof gitHubInstance;
    githubRelease: typeof githubRelease;
    manifest: typeof manifest;
    releasePR: typeof releasePR;
    releasePRClass: typeof releasePRClass;
    call: typeof call;
    runCommand: typeof runCommand;
};
export {};
